(()=>{var i="data-django-prose-editor-default";function q(o){if(o.closest(".prose-editor"))return;let r=JSON.parse(o.getAttribute(i)),{Document:n,Dropcursor:l,Gapcursor:s,Paragraph:a,HardBreak:d,Text:c,History:u,Blockquote:g,Bold:p,BulletList:h,Heading:b,HorizontalRule:k,Italic:E,ListItem:T,OrderedList:f,Strike:L,Subscript:m,Superscript:B,Underline:H,Link:S,Menu:_,HTML:D,NoSpellCheck:I,Typographic:j,createTextareaEditor:y}=DjangoProseEditor,e=(t=>P=>t!=null&&t.length?t.includes(P):!0)(r.types),z=[n,l,s,a,d,c,r.history&&u,_,r.html&&D,I,r.typographic&&j,e("blockquote")&&g,e("strong")&&p,e("bullet_list")&&h,e("heading")&&b.configure({levels:r.headingLevels||[1,2,3,4,5]}),e("horizontal_rule")&&k,e("em")&&E,e("link")&&S,(e("bullet_list")||e("ordered_list"))&&T,e("ordered_list")&&f,e("strikethrough")&&L,e("sub")&&m,e("sup")&&B,e("underline")&&H].filter(Boolean);return y(o,z)}DjangoProseEditor.initializeEditors(q,`[${i}]`);})();
